SystemOrganization addCategory: #TinyBlog!
SystemOrganization addCategory: #'TinyBlog-Components'!
SystemOrganization addCategory: #'TinyBlog-Core'!
SystemOrganization addCategory: #'TinyBlog-Manifest'!
SystemOrganization addCategory: #'TinyBlog-Teapot'!
SystemOrganization addCategory: #'TinyBlog-Teapot-Tests'!
SystemOrganization addCategory: #'TinyBlog-Tests'!

Object subclass: #TBXBlog
	instanceVariableNames: 'posts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Core'!

!TBXBlog commentStamp: 'PeterPesch 6/19/2020 12:29' prior: 0!
I represent a Tiny Blog.

I can show Posts from different Categories.

Peter Pesch, based on the code from the Pharo Mooc.
!

!TBXBlog class methodsFor: 'action' stamp: 'PeterPesch 6/12/2020 15:38'!
createDemoPosts
    "TBBlog createDemoPosts"
    self current
    writeBlogPost: ((TBXPost
        title: 'Welcome in TinyBlog'
        text: 'TinyBlog is a small blog engine made with Pharo.'
        category: 'TinyBlog') visible: true);
    writeBlogPost: ((TBXPost
        title: 'Report Pharo Sprint'
        text: 'Friday, June 12 there was a Pharo sprint / Moose dojo. It was a
nice event with more than 15 motivated sprinters. With the help
of candies, cakes and chocolate, huge work has been done'
        category: 'Pharo') visible: true);
    writeBlogPost: ((TBXPost
        title: 'Brick on top of Bloc - Preview'
        text: 'We are happy to announce the first previewversion of Brick, a new widget set created from scratch on top of Bloc. Brick is being developed primarily by Alex Syrel (together with Alain Plantec, Andrei Chis and myself), and the work is sponsored by ESUG.
Brick is part of the Glamorous Toolkit effort and will provide the basis for the new versions of the development tools.'
        category: 'Pharo') visible: true);
    writeBlogPost: ((TBXPost
        title: 'The sad story of unclassified blog posts'
        text: 'So sad that I can read this.') visible: true);
    writeBlogPost: ((TBXPost
        title: 'Working with Pharo on the Raspberry Pi'
        text: 'Hardware is getting cheaper and many new small devices like the famous Raspberry Pi provide new computation power that was one once only available on regular desktop computers.'
        category: 'Pharo') visible: true)! !

!TBXBlog class methodsFor: 'accessing' stamp: 'PeterPesch 6/26/2020 14:16'!
current
	"Return the singleton instance."
	^ self selectAll
		ifNotEmpty: [ :x | x anyOne ]
		ifEmpty: [ self new save ]
! !

!TBXBlog class methodsFor: 'class initialization' stamp: 'PeterPesch 6/18/2020 17:53'!
initialize
	self reset! !

TBXBlog initialize!

!TBXBlog class methodsFor: 'initialization' stamp: 'PeterPesch 6/26/2020 16:41'!
initializeLocalhostMongoDB
	| repository |
	repository := VOMongoRepository database: 'tinyblog'.
	repository enableSingleton.
! !

!TBXBlog class methodsFor: 'initialization' stamp: 'PeterPesch 6/26/2020 14:09'!
initializeVoyageOnMemoryDB
	VOMemoryRepository new enableSingleton! !

!TBXBlog class methodsFor: 'testing' stamp: 'PeterPesch 6/26/2020 14:02'!
isVoyageRoot
	"Indicates that instances of this class are top level document in noSQL databases"
	^ true
! !

!TBXBlog class methodsFor: 'action' stamp: 'PeterPesch 6/26/2020 16:41'!
reset
	self initializeLocalhostMongoDB! !

!TBXBlog methodsFor: 'accessing' stamp: 'PeterPesch 6/12/2020 15:01'!
allBlogPosts
	^ posts
! !

!TBXBlog methodsFor: 'accessing' stamp: 'PeterPesch 6/18/2020 17:50'!
allBlogPostsFromCategory: aCategory
	^ posts select: [ :post | post category = aCategory  ]! !

!TBXBlog methodsFor: 'accessing' stamp: 'PeterPesch 6/12/2020 15:24'!
allCategories
	^ (self allBlogPosts collect: [ :p | p category ]) asSet! !

!TBXBlog methodsFor: 'accessing' stamp: 'PeterPesch 6/19/2020 12:33'!
allVisibleBlogPosts
	^ posts select: #isVisible! !

!TBXBlog methodsFor: 'accessing' stamp: 'PeterPesch 6/12/2020 15:15'!
allVisibleBlogPostsFromCategory: aCategory 
	^ posts select: [ :post | post isVisible and: [ post category = aCategory ] ]! !

!TBXBlog methodsFor: 'initialization' stamp: 'PeterPesch 6/12/2020 14:56'!
initialize
	super initialize.
	posts := OrderedCollection new! !

!TBXBlog methodsFor: 'action' stamp: 'PeterPesch 6/26/2020 17:40'!
removeAllPosts
	"posts := OrderedCollection new."
	self allBlogPosts
		removeAll;
		compact.
	self save! !

!TBXBlog methodsFor: 'removing' stamp: 'PeterPesch 6/29/2020 10:21'!
removeLast
	posts removeLast.
	self save.
! !

!TBXBlog methodsFor: 'accessing' stamp: 'PeterPesch 6/12/2020 14:40'!
size
	^ posts size! !

!TBXBlog methodsFor: 'action' stamp: 'PeterPesch 6/26/2020 14:36'!
writeBlogPost: aPost
	"Add the blog post to the blog."
	self allBlogPosts add: aPost.
	self save! !

Object subclass: #TBXPost
	instanceVariableNames: 'title text date category visible'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Core'!

!TBXPost commentStamp: 'PeterPesch 6/19/2020 12:30' prior: 0!
I represent a Post on the Tiny Blog.

I have a tilte, text, date and category, and I may be visible.

Peter Pesch, based on the code from the Pharo Mooc.!

!TBXPost class methodsFor: 'instance creation' stamp: 'PeterPesch 6/10/2020 16:48'!
title: aTitle text: aText
	"Create a new text in the Unclassified category."

	^ self new
		title: aTitle;
		text: aText;
		yourself! !

!TBXPost class methodsFor: 'instance creation' stamp: 'PeterPesch 6/10/2020 16:48'!
title: aTitle text: aText category: aCategory
	"Create a new text in a given category."

	^ (self title: aTitle text: aText)
		category: aCategory;
		yourself! !

!TBXPost class methodsFor: 'classification' stamp: 'PeterPesch 6/10/2020 16:38'!
unclassifiedTag
	"Unclassified Category"
			
	^ 'Unclassified'! !

!TBXPost methodsFor: 'action' stamp: 'PeterPesch 6/10/2020 16:30'!
beVisible
	"Make the post visible"
			
	self visible: true! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:23'!
category
	"Return the name of the category of the post"

	^ category! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:28'!
category: anObject
	"Updates the name of the category of the post"

	category := anObject ! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:22'!
date
	"Return the date of writing"

	^ date! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:27'!
date: aDate
	"Updates the date of writing"

	date := aDate! !

!TBXPost methodsFor: 'initialization' stamp: 'PeterPesch 6/10/2020 16:42'!
initialize
	"Intialize ta new post as Unclassified"	

	super initialize.
	self category: self class unclassifiedTag.
	self date: Date today.
	self notVisible! !

!TBXPost methodsFor: 'testing' stamp: 'PeterPesch 6/10/2020 17:16'!
isUnclassified
	"Check whether post is in Unclassified category"	

	^ self category = self class unclassifiedTag! !

!TBXPost methodsFor: 'testing' stamp: 'PeterPesch 6/10/2020 17:14'!
isVisible
	"Check whether post is visible"	

	^ self visible! !

!TBXPost methodsFor: 'action' stamp: 'PeterPesch 6/10/2020 16:31'!
notVisible
	"Hide the post"

	self visible: false! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:22'!
text
	"Return the post text"
			
	^ text! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:26'!
text: aString
	"Updates the post text"

	text := aString ! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:21'!
title
	"Return the post title"
			
	^ title! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:25'!
title: aString
	"Updates the post title"

	title := aString ! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:24'!
visible
	"Return whether the post is visible or not"

	^ visible! !

!TBXPost methodsFor: 'acccessing' stamp: 'PeterPesch 6/10/2020 16:25'!
visible: aBoolean
	"Updates whether the post is visible or not"

	visible := aBoolean ! !

Object subclass: #TBXTeapotWebApp
	instanceVariableNames: 'teapot'
	classVariableNames: 'Server'
	poolDictionaries: ''
	category: 'TinyBlog-Teapot'!

!TBXTeapotWebApp commentStamp: 'PeterPesch 6/19/2020 12:50' prior: 0!
I represent a simple Web Interface for the Tiny Blog.

I access the TinyBlog API and I use the Teaport Web Platform.

Peter Pesch, based on the code from the Pharo Mooc.!

!TBXTeapotWebApp class methodsFor: 'instance creation' stamp: 'PeterPesch 6/24/2020 14:32'!
singleton
	Server ifNil: [ Server := self new start ].
	^ Server! !

!TBXTeapotWebApp class methodsFor: 'controlling' stamp: 'PeterPesch 6/24/2020 14:16'!
start
    Server ifNil: [ Server := self new start ]! !

!TBXTeapotWebApp class methodsFor: 'controlling' stamp: 'PeterPesch 6/24/2020 14:16'!
stop
    Server ifNotNil: [ :arg | Server stop. Server := nil ]! !

!TBXTeapotWebApp methodsFor: 'contents' stamp: 'PeterPesch 6/19/2020 15:45'!
allPosts
    ^ TBXBlog current allVisibleBlogPosts! !

!TBXTeapotWebApp methodsFor: 'rendering' stamp: 'PeterPesch 6/24/2020 14:42'!
errorPage
	^ String streamContents: [ :s |
		self renderPageHeaderOn: s.
		s << '<p>Oops, an error occurred</p>'.
		self renderPageFooterOn: s ]! !

!TBXTeapotWebApp methodsFor: 'contents' stamp: 'PeterPesch 6/24/2020 15:21'!
homePage
    ^ String streamContents: [ :s |
        self renderPageHeaderOn: s.
        s << '<h1>TinyBlog Web App</h1>'.
        s << '<ul>'.
        self allPosts withIndexDo: [ :aPost :index |
            s << '<li>';
            << ('<a href="/post/', index asString, '">');
            << aPost title ;
            << '</a></li>' ].
        s << '</ul>'.
        self renderPageFooterOn: s ]! !

!TBXTeapotWebApp methodsFor: 'initialization' stamp: 'PeterPesch 6/19/2020 12:51'!
initialize
    super initialize.
    teapot := Teapot configure: {
        #port -> 8081.
        #debugMode -> true }! !

!TBXTeapotWebApp methodsFor: 'contents' stamp: 'PeterPesch 6/24/2020 14:45'!
pageForPostNumber: aPostNumber
	| currentPost |
	currentPost := self allPosts at: aPostNumber ifAbsent: [ ^ self errorPage ].
	^ String streamContents: [ :s |
		self renderPageHeaderOn: s.
		s << ('<h1>', currentPost title, '</h1>').
		s << ('<h3>', currentPost date mmddyyyy, '</h3>').
		s << ('<p> Category: ', currentPost category, '</p>').
		s << ('<p>', currentPost text, '</p>').
		self renderPageFooterOn: s ]! !

!TBXTeapotWebApp methodsFor: 'rendering' stamp: 'PeterPesch 6/19/2020 15:48'!
renderPageFooterOn: aStream
    aStream << '</body></html>'! !

!TBXTeapotWebApp methodsFor: 'rendering' stamp: 'PeterPesch 6/19/2020 15:48'!
renderPageHeaderOn: aStream
    aStream << '<html><body>'! !

!TBXTeapotWebApp methodsFor: 'controlling' stamp: 'PeterPesch 6/24/2020 14:44'!
start
    teapot
        GET: '/' -> [ self homePage ];
        GET: '/post/<id>' -> [ :request | self pageForPostNumber: (request at: #id) asNumber ];
        start! !

!TBXTeapotWebApp methodsFor: 'controlling' stamp: 'PeterPesch 6/24/2020 14:17'!
stop
    teapot stop! !

!XMLNode methodsFor: '*TinyBlog' stamp: 'PeterPesch 6/24/2020 12:23'!
allElements: tagname
    "Return all descendant nodes with given tagname"
    | result |
    result := OrderedCollection new.
    self elementName = tagname ifTrue: [ result add: self ].
    self children do: [ :child | result addAll: (child allElements: tagname) ].
    ^ result.! !

!XMLNode methodsFor: '*TinyBlog' stamp: 'PeterPesch 6/23/2020 17:00'!
children
    "Return the children of this XMLNode."
    self hasChildren
        ifTrue: [ ^ self nodes collection ]
        ifFalse: [ ^ OrderedCollection new ]! !

!XMLNode methodsFor: '*TinyBlog' stamp: 'PeterPesch 6/23/2020 16:58'!
elementName 
    "Return the name of this XMLNode, if it is an element."
    self isElement
        ifTrue: [ ^ self name ]
        ifFalse: [ ^ '' ]! !

PackageManifest subclass: #ManifestTinyBlog
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Manifest'!

!ManifestTinyBlog commentStamp: '<historical>' prior: 0!
I store metadata for this package. These meta data are used by other tools such as the SmalllintManifestChecker and the critics Browser!

!ManifestTinyBlog class methodsFor: 'code-critics' stamp: 'PeterPesch 6/24/2020 14:24'!
ruleGRUsesCurlyBraceArraysRuleV1FalsePositive
	^ #(#(#(#RGMethodDefinition #(#TBXTeapotWebApp #initialize #false)) #'2020-06-24T14:24:30.614032+02:00') )! !

!ManifestTinyBlog class methodsFor: 'code-critics' stamp: 'PeterPesch 6/24/2020 15:07'!
ruleReTestClassNotInPackageWithTestEndingNameV1FalsePositive
	^ #(#(#(#RGClassDefinition #(#TBXTeapotWebAppTest)) #'2020-06-24T15:07:42.718032+02:00') )! !

WAComponent subclass: #TBXApplicationRootComponent
	instanceVariableNames: 'main'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Components'!

!TBXApplicationRootComponent commentStamp: 'PeterPesch 6/29/2020 11:47' prior: 0!
I am the entry point of this web application.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.


    Implementation Points!

!TBXApplicationRootComponent class methodsFor: 'testing' stamp: 'PeterPesch 6/29/2020 11:37'!
canBeRoot
	^ true! !

!TBXApplicationRootComponent class methodsFor: 'class initialization' stamp: 'PeterPesch 6/29/2020 11:36'!
initialize
	"self initialize"
	| app |
	app := WAAdmin register: self asApplicationAt: 'TinyBlog'.
	app
	addLibrary: JQDeploymentLibrary;
	addLibrary: JQUiDeploymentLibrary;
	addLibrary: TBSDeploymentLibrary! !

TBXApplicationRootComponent initialize!

!TBXApplicationRootComponent methodsFor: 'hooks' stamp: 'PeterPesch 6/29/2020 12:09'!
children
	^ { main }! !

!TBXApplicationRootComponent methodsFor: 'initialization' stamp: 'PeterPesch 6/29/2020 12:17'!
initialize
	super initialize.
	main := TBXPostsListComponent new.! !

!TBXApplicationRootComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:18'!
main: aComponent
	main := aComponent! !

!TBXApplicationRootComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 12:08'!
renderContentOn: html
	html render: main! !

!TBXApplicationRootComponent methodsFor: 'updating' stamp: 'PeterPesch 6/29/2020 11:40'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot beHtml5.
	anHtmlRoot title: 'TinyBlog'.! !

WAComponent subclass: #TBXCategoriesComponent
	instanceVariableNames: 'categories postsList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Components'!

!TBXCategoriesComponent commentStamp: 'PeterPesch 6/29/2020 12:33' prior: 0!
I show the list of all Categories for this tiny Blog Web Aplication.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	categories:		<Object>
	postsList:		<Object>


    Implementation Points!

!TBXCategoriesComponent class methodsFor: 'creation' stamp: 'PeterPesch 6/29/2020 13:42'!
categories: aCollectionOfCategories postsList: aTBScreen
	^ self new
		categories: aCollectionOfCategories;
		postsList: aTBScreen! !

!TBXCategoriesComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:34'!
categories
	^ categories! !

!TBXCategoriesComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:34'!
categories: aCollection
	categories := aCollection! !

!TBXCategoriesComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:34'!
postsList
	^ postsList! !

!TBXCategoriesComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:34'!
postsList: aComponent
	postsList := aComponent! !

!TBXCategoriesComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 12:58'!
renderCategoryLinkOn: html with: aCategory
	html tbsLinkifyListGroupItem
		class: 'active' if: aCategory = self postsList currentCategory;
		callback: [ self selectCategory: aCategory ];
		with: aCategory! !

!TBXCategoriesComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 12:43'!
renderContentOn: html
	html tbsListGroup: [
		html tbsListGroupItem with: [ html strong: 'Categories' ].
		categories do: [ :cat | self renderCategoryLinkOn: html with: cat ] ]! !

!TBXCategoriesComponent methodsFor: 'action' stamp: 'PeterPesch 6/29/2020 12:37'!
selectCategory: aCategory
	postsList currentCategory: aCategory! !

WAComponent subclass: #TBXHeaderComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Components'!

!TBXHeaderComponent commentStamp: 'PeterPesch 6/29/2020 12:01' prior: 0!
I am a component to appear at the top of alls components in our Web App.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.


    Implementation Points!

!TBXHeaderComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 12:01'!
renderContentOn: html
	html tbsNavbar beDefault with: [
	html tbsNavbarBrand
	url: '#';
	with: 'TinyBlog' ]! !

WAComponent subclass: #TBXPostComponent
	instanceVariableNames: 'post'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Components'!

!TBXPostComponent commentStamp: 'PeterPesch 6/29/2020 12:24' prior: 0!
I am a Screen Components which shows the Title, Date and Contents of a post.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	post:		<Object>


    Implementation Points!

!TBXPostComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:22'!
date
	^ post date! !

!TBXPostComponent methodsFor: 'initialization' stamp: 'PeterPesch 6/29/2020 12:22'!
initialize
super initialize.
post := TBXPost new.! !

!TBXPostComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:26'!
post: aPost
	post := aPost! !

!TBXPostComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 12:23'!
renderContentOn: html
	html heading level: 2; with: self title.
	html heading level: 6; with: self date.
	html text: self text! !

!TBXPostComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:22'!
text
	^ post text! !

!TBXPostComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:22'!
title
	^ post title! !

WAComponent subclass: #TBXScreenComponent
	instanceVariableNames: 'header'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Components'!

!TBXScreenComponent commentStamp: 'PeterPesch 6/29/2020 11:46' prior: 0!
I am an abstract class, to share behaviour between all our components.


For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.


    Implementation Points!

TBXScreenComponent subclass: #TBXPostsListComponent
	instanceVariableNames: 'currentCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Components'!

!TBXPostsListComponent commentStamp: 'PeterPesch 6/29/2020 12:15' prior: 0!
I am a Screen Components which lists posts from the blog.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.


    Implementation Points!

!TBXPostsListComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 14:17'!
categoriesColumnOn: html
 	| categories |   
	categories := OrderedCollection with: 'All'.
	categories addAll: self blog allCategories.
	html render:
        (TBXCategoriesComponent
            categories: categories
            postsList: self)! !

!TBXPostsListComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:39'!
currentCategory
	^ currentCategory! !

!TBXPostsListComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 12:39'!
currentCategory: anObject
	currentCategory := anObject! !

!TBXPostsListComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 13:32'!
postsColumnOn: html
    self readSelectedPosts do: [ :p |
        html render: (TBXPostComponent new post: p) ]! !

!TBXPostsListComponent methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:20'!
readSelectedPosts
	^ self currentCategory
		ifNil: [ self blog allVisibleBlogPosts ]
		ifNotNil: [ 
			self currentCategory = 'All'
				ifTrue: [ self blog allVisibleBlogPosts ]
				ifFalse: [ self blog allVisibleBlogPostsFromCategory: self currentCategory ] ]! !

!TBXPostsListComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 13:36'!
renderContentOn: html
	super renderContentOn: html.
    html tbsContainer: [
        html tbsRow
            showGrid;
            with: [ self responsiveColumnsOn: html ]
    ]
! !

!TBXPostsListComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 13:35'!
responsiveColumnsOn: html
    html tbsColumn
        extraSmallSize: 12;
        smallSize: 2;
        mediumSize: 4;
        with: [ self categoriesColumnOn: html ].
    html tbsColumn
        extraSmallSize: 12;
        smallSize: 10;
        mediumSize: 8;
        with: [ self postsColumnOn: html ] 
! !

!TBXScreenComponent methodsFor: 'acccessing' stamp: 'PeterPesch 6/29/2020 11:50'!
blog
	"Return the current blog.
	In the future we will ask the session to return the blog of the currently logged user."
	^ TBXBlog current! !

!TBXScreenComponent methodsFor: 'hooks' stamp: 'PeterPesch 6/29/2020 12:04'!
children
	^ OrderedCollection with: header! !

!TBXScreenComponent methodsFor: 'initialization' stamp: 'PeterPesch 6/29/2020 12:02'!
initialize
	super initialize.
	header := TBXHeaderComponent new.! !

!TBXScreenComponent methodsFor: 'rendering' stamp: 'PeterPesch 6/29/2020 12:05'!
renderContentOn: html
	html render: header! !

TestCase subclass: #TBXBlogTest
	instanceVariableNames: 'blog post first originalSize testSize invisiblePost'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Tests'!

!TBXBlogTest methodsFor: 'running' stamp: 'PeterPesch 6/29/2020 10:45'!
setUp
	"Initialize the Fixture"
	super setUp.

	blog := TBXBlog current.
	originalSize := blog size.
	first := TBXPost title: 'A title' text: 'A text' category: 'First Category'.
	testSize := blog size.
	invisiblePost := (TBXPost title: 'Invisible Post' text: 'text' category: 'First Category') notVisible.
	post := (TBXPost title: 'Another title' text: 'Another text' category: 'Second Category') beVisible.
! !

!TBXBlogTest methodsFor: 'running' stamp: 'PeterPesch 6/29/2020 10:24'!
tearDown
	[ blog size > originalSize ] whileTrue: [ blog removeLast ].
	super tearDown! !

!TBXBlogTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 10:25'!
testAddBlogPost
			
	| newSize |
	blog writeBlogPost: post.
	newSize := blog size.
	blog removeLast.
	self assert: newSize equals: (testSize + 1).
! !

!TBXBlogTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 10:31'!
testAllBlogPosts
	| newSize |
	blog writeBlogPost: post.
	newSize := blog allBlogPosts size.
	blog removeLast.
	self assert: newSize equals: (testSize + 1).
! !

!TBXBlogTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 10:32'!
testAllBlogPostsFromCategory
	| before after |
	before := (blog allBlogPostsFromCategory: 'First Category') size.
	blog writeBlogPost: first.
	after := (blog allBlogPostsFromCategory: 'First Category') size.
	blog removeLast.
	self assert: after equals: before + 1
! !

!TBXBlogTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 10:40'!
testAllCategories
	| before after |
	before := blog allCategories size.
	blog writeBlogPost: post.
	after := blog allCategories size.
	blog removeLast.
	self assert: after equals: before + 1! !

!TBXBlogTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 10:46'!
testAllVisibleBlogPosts
	| before inbetween after |
	before := blog allVisibleBlogPosts size.
	blog writeBlogPost: invisiblePost .
	inbetween := blog allVisibleBlogPosts size.
	blog writeBlogPost: post.
	after := blog allVisibleBlogPosts size.
	blog removeLast.
	blog removeLast.
	self assert: inbetween equals: before.
	self assert: after equals: before + 1
! !

!TBXBlogTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 10:50'!
testAllVisibleBlogPostsFromCategory
	| before1 after1 before2 after2 |
	before1 := (blog allVisibleBlogPostsFromCategory: 'First Category') size.
	before2 := (blog allVisibleBlogPostsFromCategory: 'Second Category') size.
	blog writeBlogPost: post.
	after1 := (blog allVisibleBlogPostsFromCategory: 'First Category') size.
	after2 := (blog allVisibleBlogPostsFromCategory: 'Second Category') size.
	blog removeLast.
	self assert: after1 equals: before1.
	self assert: after2 equals: before2 + 1
! !

!TBXBlogTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 11:01'!
testUnclassifiedBlogPosts
	| before after |
	before := (blog allBlogPosts select: [ :p | p isUnclassified ]) size.
	blog writeBlogPost: ((TBXPost
   		 title: 'The sad story of unclassified blog posts'
       text: 'So sad that I can read this.') visible: true).
	after := (blog allBlogPosts select: [ :p | p isUnclassified ]) size.
	blog removeLast.
	self assert: after equals: before + 1! !

TestCase subclass: #TBXPostTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Tests'!

!TBXPostTest methodsFor: 'tests' stamp: 'PeterPesch 6/10/2020 17:02'!
testPostIsCreatedCorrectly
	"Check whether a new blog post created correctly"

	| post |
	post := TBXPost
		title: 'Welcome to my blog'
		text: 'TinyBlog is a small blog engine made with Pharo.'
		category: 'TinyBlog'.
	self assert: post title equals: 'Welcome to my blog'.
	self assert: post text equals: 'TinyBlog is a small blog engine made with Pharo.'.
	self assert: post category equals: 'TinyBlog'.
! !

!TBXPostTest methodsFor: 'tests' stamp: 'PeterPesch 6/10/2020 17:17'!
testWithoutCategoryIsUnclassified
	"Check whether a new blog post without category is Unclassified"

	| post |
	post := TBXPost
		title: 'Welcome to my blog'
		text: 'TinyBlog is a small blog engine made with Pharo.'.
	self assert: post title equals: 'Welcome to my blog'.
	self assert: post isUnclassified.
	self deny: post isVisible.
! !

TestCase subclass: #TBXTeapotWebAppTest
	instanceVariableNames: 'webAddress'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'TinyBlog-Teapot-Tests'!

!TBXTeapotWebAppTest methodsFor: 'running' stamp: 'PeterPesch 6/24/2020 15:35'!
setUp
    "Hooks that subclasses may override to define the fixture of test."
    super setUp.
    webAddress := 'http://localhost:8081'.! !

!TBXTeapotWebAppTest methodsFor: 'tests' stamp: 'PeterPesch 6/26/2020 16:54'!
testAllPosts
	| result tree node originalSize |
	TBXTeapotWebApp stop.
	TBXBlog reset.
	TBXTeapotWebApp start.
	result := ZnEasy get: webAddress.
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'ul') at: 1.
	originalSize := node nodes size.
	TBXBlog createDemoPosts.
	result := ZnEasy get: webAddress.
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'ul') at: 1.
	self assert: node nodes size equals: (originalSize + 5).
	TBXBlog createDemoPosts.
	result := ZnEasy get: webAddress.
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'ul') at: 1.
	self assert: node nodes size equals: (originalSize + 10).
! !

!TBXTeapotWebAppTest methodsFor: 'tests' stamp: 'PeterPesch 6/24/2020 15:35'!
testErrorPage
	| result tree node |
	TBXTeapotWebApp stop.
	TBXTeapotWebApp start.
	TBXBlog reset.
	TBXBlog createDemoPosts.
	result := ZnEasy get: (webAddress , '/post/9').
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'p') at: 1.
	node := node nodes at: 1.
	self assert: node string equals: 'Oops, an error occurred'! !

!TBXTeapotWebAppTest methodsFor: 'tests' stamp: 'PeterPesch 6/24/2020 13:54'!
testHomepage
	| result tree node |
	TBXTeapotWebApp stop.
	TBXTeapotWebApp start.
	result := ZnEasy get: webAddress.
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'h1') at: 1.
	node := node nodes at: 1.
	self assert: node string equals: 'TinyBlog Web App'! !

!TBXTeapotWebAppTest methodsFor: 'tests' stamp: 'PeterPesch 6/25/2020 11:06'!
testLinksToPosts
	| result tree node title link dict |
	TBXTeapotWebApp stop.
	TBXTeapotWebApp start.
	TBXBlog reset.
	TBXBlog createDemoPosts.
	result := ZnEasy get: (webAddress).
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'li') at: 3.
	node := (node allElements: 'a') at: 1.

	dict := node attributes.
	link := dict at: (dict orderedKeys at: 1).
	title := (node nodes at: 1) string.

	result := ZnEasy get: (webAddress , link).	
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'h1') at: 1.
	node := node nodes at: 1.
	self assert: node string equals: title! !

!TBXTeapotWebAppTest methodsFor: 'tests' stamp: 'PeterPesch 6/24/2020 15:35'!
testPageForPostNumber
	| result tree node |
	TBXTeapotWebApp stop.
	TBXTeapotWebApp start.
	TBXBlog reset.
	TBXBlog createDemoPosts.
	result := ZnEasy get: (webAddress , '/post/1').
	tree := (XMLDOMParser on: result entity string) parseDocument.
	node := (tree allElements: 'h1') at: 1.
	node := node nodes at: 1.
	self assert: node string equals: 'Welcome in TinyBlog'! !

!TBXTeapotWebAppTest methodsFor: 'tests' stamp: 'PeterPesch 6/23/2020 16:52'!
testStart
    TBXTeapotWebApp stop.
    TBXTeapotWebApp start.
    self shouldnt: (ZnEasy get: webAddress) raise: Error.! !

!TBXTeapotWebAppTest methodsFor: 'tests' stamp: 'PeterPesch 6/24/2020 12:30'!
testStop
    | timeOut |
    TBXTeapotWebApp start.
    TBXTeapotWebApp stop.
    timeOut := false.
    [ ZnEasy get: webAddress ] on: ConnectionTimedOut do: [ :excepion | timeOut := true ].
    self assert: timeOut.! !

TBXBlog initialize!

TBXApplicationRootComponent initialize!
